******************************
Welcome to Kanon documentation
******************************

.. include:: ../README.rst

More info
_________

Table of content
================

.. toctree::
  :maxdepth: 2

  tables/index.rst
  units/index.rst
  calendars/index.rst
  examples.rst

Index and search
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
